$title Policy Costs

**----------- Nestor-Pasurka Data on Environmental Protection (EP) Input Purchases -------------**

* include shares on environmental protection industry
parameter 
	EP_inputs	percent of EP costs by input type and purchasing industry (from input file) 
	EP_inputs_ELE
	EP_shares	share-percentage of EP costs by input type and purchasing industry (used in calculations) 
	chk_ELE_EP
	chk_EP;

$include ..\data\EP_cost_data_%size%.dat

EP_shares(r,s,g)	= EP_inputs(s,g);
EP_shares(r,s,"L")	= EP_inputs(s,"L");
EP_shares(r,s,"K")	= EP_inputs(s,"K");

* rescale if missing input data in IMPLAN/EMPAX
EP_shares(r,s,g)$(id0(r,g,s) eq 0)	= 0;
EP_shares(r,s,"L")			= EP_shares(r,s,"L") + sum(g$(id0(r,g,s) eq 0), EP_inputs(s,g));
EP_shares(r,s,g)$(id0(r,g,s) eq 0)	= 0;

chk_EP(r,s) = sum(g, EP_shares(r,s,g)) + EP_shares(r,s,"L") + EP_shares(r,s,"K");

chk_EP("USA","total") = sum((r,s), chk_EP(r,s));
chk_EP("USA","card") = card(r)*card(s);

* rescale ELE purchases of COL and GAS (or mining in EP_industry.xls)

chk_ELE_EP(r,g,"pre")		= EP_shares(r,"ELE",g); 
chk_ELE_EP(r,"L","pre")		= EP_shares(r,"ELE","L");
chk_ELE_EP(r,"K","pre")		= EP_shares(r,"ELE","K");
chk_ELE_EP(r,"new_total","pre")	= sum(g, chk_ELE_EP(r,g,"pre")) + chk_ELE_EP(r,"L","pre") + chk_ELE_EP(r,"K","pre");

EP_inputs("ELE","mining")	= 0;

EP_inputs_ELE(r,"ELE",g)	= (1-EP_inputs("ELE","mining")) * EP_shares(r,"ELE",g) / (sum(gg, EP_shares(r,"ELE",gg)) + EP_shares(r,"ELE","L") + EP_shares(r,"ELE","K"));
EP_inputs_ELE(r,"ELE","L")	= (1-EP_inputs("ELE","mining")) * EP_shares(r,"ELE","L") / (sum(gg, EP_shares(r,"ELE",gg)) + EP_shares(r,"ELE","L") + EP_shares(r,"ELE","K"));
EP_inputs_ELE(r,"ELE","K")	= (1-EP_inputs("ELE","mining")) * EP_shares(r,"ELE","K") / (sum(gg, EP_shares(r,"ELE",gg)) + EP_shares(r,"ELE","L") + EP_shares(r,"ELE","K"));

EP_shares(r,"ELE",g)		= 0;
EP_shares(r,"ELE","L")		= 0;
EP_shares(r,"ELE","K")		= 0;

EP_shares(r,"ELE",g)		= EP_inputs_ELE(r,"ELE",g);
EP_shares(r,"ELE","L")		= EP_inputs_ELE(r,"ELE","L");
EP_shares(r,"ELE","K")		= EP_inputs_ELE(r,"ELE","K");

EP_shares(r,"ELE","COL")	= EP_inputs("ELE","mining") * FuelDollar1(r,"COL","ELE","2005") / (FuelDollar1(r,"COL","ELE","2005")+FuelDollar1(r,"GAS","ELE","2005"));
EP_shares(r,"ELE","GAS")	= EP_inputs("ELE","mining") * FuelDollar1(r,"GAS","ELE","2005") / (FuelDollar1(r,"COL","ELE","2005")+FuelDollar1(r,"GAS","ELE","2005"));

chk_ELE_EP(r,g,"post")		= EP_shares(r,"ELE",g); 
chk_ELE_EP(r,"L","post")	= EP_shares(r,"ELE","L");
chk_ELE_EP(r,"K","post")	= EP_shares(r,"ELE","K");
chk_ELE_EP(r,"new_total","post")= sum(g, chk_ELE_EP(r,g,"post")) + chk_ELE_EP(r,"L","post") + chk_ELE_EP(r,"K","post");

option chk_ELE_EP:6;
display chk_ELE_EP;


option chk_EP:3:0:1;
display EP_shares,chk_EP;

abort$(round(sum((r,s),chk_EP(r,s)),3) ne (card(r)*card(s))) "Error in EP industries.";


**----------- CoST Model -------------**
set post2005(yr) /2005,2010,2015/;
set post2015(yr) /2020,2025,2030,2035,2040,2045,2050/; 


$if not %states%==USA $goto indivstates
set mapSTATES(r,states) /
NRTH.(pa,nj,md,de,dc,ny,me,ct,ma,nh,ri,vt)
SOTH.(fl,nc,sc,va,al,ga,la,ms,ar,tn)
MIDW.(in,mi,oh,ky,wv,ia,il,mo,wi)
PLNS.(tx,mn,ne,nd,sd,ks,ok)
WEST.(or,wa,id,mt,ut,nv,wy,az,co,nm,ca,ak,hi) /;
$goto startpolicy

$label indivstates
set mapSTATES(r,states) /
%states%.%states%
/;

$label startpolicy
parameter
	CoST_deflator
	Comp_Costs_2010(*,*)	Compliance costs in 2010
	Comp_Costs_2015(*,*)	Compliance costs in 2010
	Comp_Costs_2020(*,*)	Compliance costs in 2020	
	CoST_data		Data from CoST model on industry costs
	CoST_data_RES		Data from CoST model on RES residential costs
	CoST_data_RES_MAN	Data from CoST model on RES transport costs
	CoST_data_RES_SRV	Data from CoST model on RES transport costs
	CoST_data_RES_OIL	Data from CoST model on RES transport costs
	CoST_data_RES_HLT	Health expenditure data
	HH_incadj		Household income adjustment for RES residential costs
	state_rough_share(*,*)	Rough estimates of state distributions
	rough_share
	rough_sum
;

$libinclude xlimport Comp_Costs_2010  ..\Inputs\pvtcosts.xls Comp_costs_2010
$libinclude xlimport Comp_Costs_2020  ..\Inputs\pvtcosts.xls Comp_costs_2020

Comp_costs_2010("RES_HLT","US") = 0;
Comp_costs_2015("RES_HLT","US") = 0;
Comp_costs_2020("RES_HLT","US") = 0;

* NEW health expenditures July 2010 ------------------------------*
*$ontext
$if %scenario%==812_cbh	Comp_costs_2010("RES_HLT","west") = 2.073;
$if %scenario%==812_cbh	Comp_costs_2010("RES_HLT","plns") = 0.834;
$if %scenario%==812_cbh	Comp_costs_2010("RES_HLT","midw") = 3.367;
$if %scenario%==812_cbh	Comp_costs_2010("RES_HLT","soth") = 2.380;
$if %scenario%==812_cbh	Comp_costs_2010("RES_HLT","nrth") = 3.282;

$if %scenario%==812_cbh	Comp_costs_2015("RES_HLT","west") = 3.305;
$if %scenario%==812_cbh	Comp_costs_2015("RES_HLT","plns") = 1.248;
$if %scenario%==812_cbh	Comp_costs_2015("RES_HLT","midw") = 4.647;
$if %scenario%==812_cbh	Comp_costs_2015("RES_HLT","soth") = 3.546;
$if %scenario%==812_cbh	Comp_costs_2015("RES_HLT","nrth") = 4.660;

$if %scenario%==812_cbh	Comp_costs_2020("RES_HLT","west") = 4.049;
$if %scenario%==812_cbh	Comp_costs_2020("RES_HLT","plns") = 1.439;
$if %scenario%==812_cbh	Comp_costs_2020("RES_HLT","midw") = 4.940;
$if %scenario%==812_cbh	Comp_costs_2020("RES_HLT","soth") = 4.063;
$if %scenario%==812_cbh	Comp_costs_2020("RES_HLT","nrth") = 5.103;
*$offtext

parameter chksum2010,chksum2015,chksum2020;
chksum2010 = sum(r,comp_costs_2010("res_hlt",r));
chksum2015 = sum(r,comp_costs_2015("res_hlt",r));
chksum2020 = sum(r,comp_costs_2020("res_hlt",r));
display chksum2010,chksum2015,chksum2020;

* assign costs for 2005, 2015, post 2020
Cost_data_RES_HLT(r,"hlt",post2005)	= 0.96845 * Comp_costs_2010("RES_hlt",r) * population(r,post2005) / population(r,"2010");
CoST_data_RES_HLT(r,"hlt","2015")	= 0.96845 * Comp_costs_2015("RES_hlt",r);
CoST_data_RES_HLT(r,"hlt",post2015)	= 0.96845 * Comp_costs_2020("RES_hlt",r) * population(r,post2015) / population(r,"2020");

*-----bring in compliance costs-----*
* convert from $1999 to $2005 (BEA GDP deflator)
CoST_deflator = 1.152488;

display comp_costs_2010,comp_costs_2020;

Comp_costs_2010(s,r)		= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2010(s,states)) / 1e+3;
Comp_costs_2010("RES",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2010("RES",states)) / 1e+3;
Comp_costs_2010("RES_MAN",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2010("RES_MAN",states)) / 1e+3;
Comp_costs_2010("RES_OIL",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2010("RES_OIL",states)) / 1e+3;
Comp_costs_2010("RES_SRV",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2010("RES_SRV",states)) / 1e+3;

Comp_costs_2020(s,r)		= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2020(s,states)) / 1e+3;
Comp_costs_2020("RES",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2020("RES",states)) / 1e+3;
Comp_costs_2020("RES_MAN",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2020("RES_MAN",states)) / 1e+3;
Comp_costs_2020("RES_OIL",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2020("RES_OIL",states)) / 1e+3;
Comp_costs_2020("RES_SRV",r)	= CoST_deflator * sum(states$mapSTATES(r,states), Comp_costs_2020("RES_SRV",states)) / 1e+3;

*  check EV percentages
parameter
	evchk1 
	evchk2
;
evchk1(t)= sum((r,hh),pref(t)*(cl.l(r,hh,t)*cl0(r,hh)));
*-------------------------------------------------------------------*

display comp_costs_2010,comp_costs_2020;

** set of non-agriculture, non-energy industries to scale COM costs (nonassigned commercial costs) for mobile sources
set scom(s); scom(s) = g(s) - nrg(s) - agr(s); alias (scom,sscom);
alias (man,sman);

* add in growth in costs based on increase in output values
CoST_data(r,s,post2005)		= Comp_costs_2010(s,r) * (ValueOut1(r,s,post2005) / ValueOut1(r,s,"2010"));
CoST_data(r,s,post2015)		= Comp_costs_2020(s,r) * (ValueOut1(r,s,post2015) / ValueOut1(r,s,"2020"));

* assign costs in each year
CoST_data_RES(r,post2005)	= Comp_costs_2010("RES",r) * population(r,post2005) / population(r,"2010");
CoST_data_RES(r,post2015)	= Comp_costs_2020("RES",r) * population(r,post2015) / population(r,"2020");

CoST_data_RES_MAN(r,man,post2005)	= (Comp_costs_2010("RES_MAN",r) * (population(r,post2005) / population(r,"2010")))
						* (sum(hh,(cd0_MVman(r,hh,man)))/(sum((hh,sman),cd0_MVman(r,hh,sman))));
CoST_data_RES_MAN(r,man,post2015)	= (Comp_costs_2020("RES_MAN",r) * (population(r,post2015) / population(r,"2020")))
						* (sum(hh,(cd0_MVman(r,hh,man)))/(sum((hh,sman),cd0_MVman(r,hh,sman))));

CoST_data_RES_SRV(r,"SRV",post2005)	= Comp_costs_2010("RES_SRV",r) * population(r,post2005) / population(r,"2010");
CoST_data_RES_SRV(r,"SRV",post2015)	= Comp_costs_2020("RES_SRV",r) * population(r,post2015) / population(r,"2020");

CoST_data_RES_OIL(r,"oil",post2005)	= Comp_costs_2010("RES_OIL",r) * population(r,post2005) / population(r,"2010");
CoST_data_RES_OIL(r,"oil",post2015)	= Comp_costs_2020("RES_OIL",r) * population(r,post2015) / population(r,"2020");


display cost_data, cost_data_RES, cost_data_RES_MAN, cost_data_RES_SRV, cost_data_RES_OIL, cost_data_RES_HLT;

parameter engineering;

engineering(r,s,t)			= CoST_data(r,s,t);
engineering(r,"ACN",t)			= sum(s, engineering(r,s,t));
engineering(r,"RES",t)			= CoST_data_RES(r,t);
engineering(r,"RES_MAN",t)		= sum(man,CoST_data_RES_MAN(r,man,t));
engineering(r,"RES_SRV",t)		= CoST_data_RES_SRV(r,"SRV",t);
engineering(r,"RES_OIL",t)		= CoST_data_RES_OIL(r,"OIL",t);
engineering(r,"RES_HLT",t)		= CoST_data_RES_HLT(r,"HLT",t);

engineering(r,"Total",t)		= engineering(r,"ACN",t)
					+ engineering(r,"RES",t) 
					+ engineering(r,"RES_MAN",t)
					+ engineering(r,"RES_SRV",t)
					+ engineering(r,"RES_OIL",t)
					+ engineering(r,"RES_HLT",t);

engineering("US",s,t)			= sum(r, engineering(r,s,t));
engineering("US","ACN",t)		= sum((r,s), engineering(r,s,t));
engineering("US","RES",t)		= sum(r, engineering(r,"RES",t));
engineering("US","RES_MAN",t)		= sum(r, engineering(r,"RES_MAN",t));
engineering("US","RES_SRV",t)		= sum(r, engineering(r,"RES_SRV",t));
engineering("US","RES_OIL",t)		= sum(r, engineering(r,"RES_OIL",t));
engineering("US","RES_HLT",t)		= sum(r, engineering(r,"RES_HLT",t));

engineering("US","Total",t)		= engineering("US","ACN",t) 
					+ engineering("US","RES",t)
					+ engineering("US","RES_MAN",t)
					+ engineering("US","RES_SRV",t)
					+ engineering("US","RES_OIL",t)
;

display engineering;

*------------------------------------------------------------------------------------------*
* adjust phi to ensure intermediate and factor demand is not negative
parameter 
	maxshare	maximum ratio of cost to bau expenditure on inputs
	factorshare	share of excess cost assigned to K,L
	maxcost		maximum cost that can be applied to input
	EP_cost		cost assigned to input using EP shares
	assign_cost	cost to be assigned to input
	chk_assign
	maxcheck	difference between maximum and assigned costs
	lostcost	total remaining unassigned costs after maximums applied by sector
;

maxshare(r,g,s)		= 0.5;
maxshare(r,"l",s)	= 0.5;
maxshare(r,"k",s)	= 0.5;

maxshare("NRTH",g,"GAS")	= 0.6;
maxshare("NRTH","k","GAS")	= 0.6;
maxshare("NRTH","L","GAS")	= 0.6;

factorshare(r,s,"k",t)	= 0.5;
factorshare(r,s,"l",t)	= 0.5;

* want maximum spending on compliance cost for intermediate g in sector s to be maxshare 
* of sector s purchases of input g in baseline.

maxcost(r,g,s,t)	= maxshare(r,g,s)*(pa1(r,g,t)/pcnum_reg1(r,t))*intgood.l(r,g,s,t);
maxcost(r,"l",s,t)	= maxshare(r,"l",s)*(pl1(r,t)/pcnum_reg1(r,t))*emply1(r,s,t);
maxcost(r,"k",s,t)	= maxshare(r,"k",s)*(rk1(r,t)/pcnum_reg1(r,t))*capy1(r,s,t);

EP_cost(r,g,s,t)	= EP_shares(r,s,g)*cost_data(r,s,t);
EP_cost(r,"l",s,t)	= EP_shares(r,s,"l")*cost_data(r,s,t);
EP_cost(r,"k",s,t)	= EP_shares(r,s,"k")*cost_data(r,s,t);

assign_cost(r,g,s,t)	= min(maxcost(r,g,s,t),EP_cost(r,g,s,t));
assign_cost(r,"l",s,t)	= min(maxcost(r,"l",s,t),EP_cost(r,"l",s,t));
assign_cost(r,"k",s,t)	= min(maxcost(r,"k",s,t),EP_cost(r,"k",s,t));

maxcheck(r,g,s,t)	= maxcost(r,g,s,t) - assign_cost(r,g,s,t);
maxcheck(r,"l",s,t)	= maxcost(r,"l",s,t) - assign_cost(r,"l",s,t);
maxcheck(r,"k",s,t)	= maxcost(r,"k",s,t) - assign_cost(r,"k",s,t);

lostcost(r,s,t)		= sum(g,(EP_cost(r,g,s,t) - assign_cost(r,g,s,t)))
				+ (EP_cost(r,"l",s,t) - assign_cost(r,"l",s,t))
				+ (EP_cost(r,"k",s,t) - assign_cost(r,"k",s,t));

parameter lost_total		total lost costs
; 
lost_total(t) = sum((r,s),lostcost(r,s,t));
display lost_total;

*assign missing costs to capital and labor
assign_cost(r,"l",s,t)	= assign_cost(r,"l",s,t) + min(maxcheck(r,"l",s,t), (factorshare(r,s,"l",t) * lostcost(r,s,t))); 
assign_cost(r,"k",s,t)	= assign_cost(r,"k",s,t) + min(maxcheck(r,"k",s,t), (factorshare(r,s,"k",t) * lostcost(r,s,t))); 

maxcheck(r,"l",s,t)	= maxcost(r,"l",s,t) - assign_cost(r,"l",s,t);
maxcheck(r,"k",s,t)	= maxcost(r,"k",s,t) - assign_cost(r,"k",s,t);

lostcost(r,s,t)		= sum(g,(EP_cost(r,g,s,t) - assign_cost(r,g,s,t)))
				+ (EP_cost(r,"l",s,t) - assign_cost(r,"l",s,t))
				+ (EP_cost(r,"k",s,t) - assign_cost(r,"k",s,t));

lost_total(t) = sum((r,s),lostcost(r,s,t));
display lost_total;

* assign excess factor costs to other factor if possible

assign_cost(r,"l",s,t) = assign_cost(r,"l",s,t) + min(maxcheck(r,"l",s,t), lostcost(r,s,t));
assign_cost(r,"k",s,t) = assign_cost(r,"k",s,t) + min(maxcheck(r,"k",s,t), lostcost(r,s,t));

maxcheck(r,"l",s,t)	= maxcost(r,"l",s,t) - assign_cost(r,"l",s,t);
maxcheck(r,"k",s,t)	= maxcost(r,"k",s,t) - assign_cost(r,"k",s,t);

lostcost(r,s,t)		= sum(g,(EP_cost(r,g,s,t) - assign_cost(r,g,s,t)))
				+ (EP_cost(r,"l",s,t) - assign_cost(r,"l",s,t))
				+ (EP_cost(r,"k",s,t) - assign_cost(r,"k",s,t));

lost_total(t) = sum((r,s),lostcost(r,s,t));
display lost_total;

chk_assign(r,s,g,t)	= round(assign_cost(r,g,s,t), 5);
chk_assign(r,s,"l",t)	= round(assign_cost(r,"l",s,t), 5);
chk_assign(r,s,"k",t)	= round(assign_cost(r,"k",s,t), 5);

option chk_assign:3:3:1;
display chk_assign;

* if costs cannot be assigned to factors, assign to other intermediates

parameter
	exfrac		fraction of remaining costs that can be applied to input;

exfrac(r,g,s,t)		= maxcheck(r,g,s,t)/sum(gg,maxcheck(r,gg,s,t));

assign_cost(r,g,s,t) = assign_cost(r,g,s,t) + min(maxcheck(r,g,s,t), (exfrac(r,g,s,t) * lostcost(r,s,t)));

	
*check that all costs have been applied

lostcost(r,s,t)		= sum(g,(EP_cost(r,g,s,t) - assign_cost(r,g,s,t)))
				+ (EP_cost(r,"l",s,t) - assign_cost(r,"l",s,t))
				+ (EP_cost(r,"k",s,t) - assign_cost(r,"k",s,t));

lost_total(t) = sum((r,s),lostcost(r,s,t));

parameter 
	assign_total		total assigned costs
	total_all		total assigned plus lost costs (should match ACN costs)
	;

assign_total(t)	= sum((r,s), sum(g, assign_cost(r,g,s,t)) + assign_cost(r,"l",s,t) + assign_cost(r,"k",s,t));
total_all(t)	= assign_total(t) + lost_total(t); 

display assign_cost, assign_total, lost_total, total_all;

parameter chk_phi_cost, chk_phi_cons;

*------------------------------------------------------------------------*
* compute phi_cost parameters to remove compliance costs from industries

phi_cost(r,g,s,t)$(pa1(r,g,t) * intgood.l(r,g,s,t))	
				= 1 + ( ((-1)*assign_cost(r,g,s,t) * pcnum_reg1(r,t) )
				/ (pa1(r,g,t) * intgood.l(r,g,s,t)) );

phi_cost(r,"labor",s,t)$(pl1(r,t) * emply1(r,s,t))
				= 1 + ( ((-1)*assign_cost(r,"l",s,t) * pcnum_reg1(r,t) )
				/ (pl1(r,t) * emply1(r,s,t)) );

phi_cost(r,"capital",s,t)$(rk1(r,t) * capy1(r,s,t))
				= 1 + ( ((-1)*assign_cost(r,"k",s,t) * pcnum_reg1(r,t) )
				/ (rk1(r,t) * capy1(r,s,t)) );


chk_phi_cost(r,s,g,t)$(phi_cost(r,g,s,t) ne 1)			= phi_cost(r,g,s,t);
chk_phi_cost(r,s,"labor",t)$(phi_cost(r,"labor",s,t) ne 1)	= phi_cost(r,"labor",s,t);
chk_phi_cost(r,s,"capital",t)$(phi_cost(r,"capital",s,t) ne 1)	= phi_cost(r,"capital",s,t);

display phi_cost,chk_phi_cost;

* income adjustment to handle residential costs by reducing consumption
mact_incadj(r,hh,t)		= (-1) * (HHincome1(r,hh,t)/sum(hhh,HHincome1(r,hhh,t)))*CoST_data_RES(r,t);

display mact_incadj;

* household costs:
* adjust quantities of transportation, health goods entering consumption 

phi_cons(r,man,hh,t)$(pa1(r,man,t)*cons_tran.l(r,hh,man,t)) 
	= 1 + (((cd0_MVman(r,hh,man)/(sum(hhh,cd0_MVman(r,hhh,man))))*(-1)*CoST_data_RES_MAN(r,man,t)*pcnum_reg1(r,t))
	/ (pa1(r,man,t)*cons_tran.l(r,hh,man,t)));

phi_cons(r,"srv",hh,t)$(pa1(r,"srv",t)*cons_tran.l(r,hh,"srv",t)) 
	= 1 + (((cd0_MVsrv(r,hh,"srv")/(sum(hhh,cd0_MVsrv(r,hhh,"srv"))))*(-1)*CoST_data_RES_SRV(r,"srv",t)*pcnum_reg1(r,t))
	/ (pa1(r,"srv",t)*cons_tran.l(r,hh,"srv",t)));

phi_cons(r,"OIL",hh,t)$(pa1(r,"OIL",t)*cons_tran.l(r,hh,"OIL",t)) 
	= 1 + (((cd0_moto(r,hh)/(sum(hhh,cd0_moto(r,hhh))))*(-1)*CoST_data_RES_OIL(r,"OIL",t)*pcnum_reg1(r,t))
	/ (pa1(r,"OIL",t)*cons_tran.l(r,hh,"OIL",t)));


phi_cons(r,"HLT",hh,t)$(pa1(r,"HLT",t)*cons_good.l(r,hh,"HLT",t)) 
	= 1 + (((cd0(r,hh,"hlt")/(sum(hhh,cd0(r,hhh,"hlt"))))*CoST_data_RES_HLT(r,"HLT",t)*pcnum_reg1(r,t))
	/ (pa1(r,"HLT",t)*cons_good.l(r,hh,"HLT",t)));


chk_phi_cons(r,g,t)$(phi_cons(r,g,"HH1",t) ne 1)	= phi_cons(r,g,"HH1",t);

display phi_cons,chk_phi_cons;

* 7/19/10
* apply oil cost as tax instead of quantity adjustment--------------------*
phi_cons(r,"OIL",hh,t) = 1;

t_cons(r,"oil",hh,t) = (-1) * ((cd0_moto(r,hh)/(sum(hhh,cd0_moto(r,hhh)))) * CoST_data_RES_OIL(r,"OIL",t) * pcnum_reg1(r,t) 
		/ (pa1(r,"OIL",t) * pcd0(r,"oil") * fuelmoto1(r,hh,t)));

display t_cons;

* apply reduction in size of labor force-----------------------*

*$ontext
parameter lab_reduction;

lab_reduction(r,t) = 0;

* new labor force impacts July 2010 --------------------------*
$if %scenario%==812_cb	lab_reduction("west","2010") = 0.0026;
$if %scenario%==812_cb	lab_reduction("plns","2010") = 0.0017;
$if %scenario%==812_cb	lab_reduction("midw","2010") = 0.0043;
$if %scenario%==812_cb	lab_reduction("soth","2010") = 0.0028;
$if %scenario%==812_cb	lab_reduction("nrth","2010") = 0.0036;
						       	     
$if %scenario%==812_cb	lab_reduction("west","2015") = 0.0039;
$if %scenario%==812_cb	lab_reduction("plns","2015") = 0.0024;
$if %scenario%==812_cb	lab_reduction("midw","2015") = 0.0057;
$if %scenario%==812_cb	lab_reduction("soth","2015") = 0.0040;
$if %scenario%==812_cb	lab_reduction("nrth","2015") = 0.0049;
						       	     
$if %scenario%==812_cb	lab_reduction("west","2020") = 0.0050;
$if %scenario%==812_cb	lab_reduction("plns","2020") = 0.0029;
$if %scenario%==812_cb	lab_reduction("midw","2020") = 0.0067;
$if %scenario%==812_cb	lab_reduction("soth","2020") = 0.0049;
$if %scenario%==812_cb	lab_reduction("nrth","2020") = 0.0059;

$if %scenario%==812_cbh	lab_reduction("west","2010") = 0.0026;
$if %scenario%==812_cbh	lab_reduction("plns","2010") = 0.0017;
$if %scenario%==812_cbh	lab_reduction("midw","2010") = 0.0043;
$if %scenario%==812_cbh	lab_reduction("soth","2010") = 0.0028;
$if %scenario%==812_cbh	lab_reduction("nrth","2010") = 0.0036;
						       	     
$if %scenario%==812_cbh	lab_reduction("west","2015") = 0.0039;
$if %scenario%==812_cbh	lab_reduction("plns","2015") = 0.0024;
$if %scenario%==812_cbh	lab_reduction("midw","2015") = 0.0057;
$if %scenario%==812_cbh	lab_reduction("soth","2015") = 0.0040;
$if %scenario%==812_cbh	lab_reduction("nrth","2015") = 0.0049;
						       	     
$if %scenario%==812_cbh	lab_reduction("west","2020") = 0.0050;
$if %scenario%==812_cbh	lab_reduction("plns","2020") = 0.0029;
$if %scenario%==812_cbh	lab_reduction("midw","2020") = 0.0067;
$if %scenario%==812_cbh	lab_reduction("soth","2020") = 0.0049;
$if %scenario%==812_cbh	lab_reduction("nrth","2020") = 0.0059;
*-------------------------------------------------------------*

lab_reduction(r,"2005")		= lab_reduction(r,"2010") - ((lab_reduction(r,"2010") + lab_reduction(r,"2020"))/2-lab_reduction(r,"2010"));
lab_reduction(r,post2020)	= lab_reduction(r,"2020");

* apply regional labor force reductions (by region from iec)
lab_endow(r,hh,t)	= lab_endow(r,hh,t) * (1 - lab_reduction(r,t));

*----------------------------------------------------------------------------*

$include dynamic.gen
solve dynamic using mcp;

$include findings2.gms

